==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/GetBatchDetail.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchDetail](
	@VCC VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET XACT_ABORT, NOCOUNT ON

	-- VERIFICAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
	IF @VCC IS NULL OR @BatchTypeName IS NULL OR @BatchTypeId IS NULL 
		-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
		RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

	-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
	IF @BatchTypeName <> 'TRANSCRIPTION' AND @BatchTypeName <> 'STUDY' AND @BatchTypeName <> 'EVALUATION_PLAN'
		-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
		RAISERROR('DATABASE_ERROR_UNKNOWN_BATCH_TYPENAME', 16, 16)

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		
		-- DEPENDIENDO DEL BATCHTYPENAME CONSULTAMOS A UNA TABLA DIFERENTE
		IF @BatchTypeName = 'TRANSCRIPTION'
		BEGIN
			-- HACEMOS LA BUSQUEDA EN LA TABLA CORRESPONDIENTE SEGUN EL TIPO DE BATCH
			SELECT P.[VCC]						'vcc',
					@BatchTypeName				'batchTypeName',
					P.[Name]					'batchTypeId',
					P.[Description]				'description',
					p.[Percentage]				'percentage',
					P.[Status]					'status',
					P.[StatusDescription]		'statusDescription',
					B.[IsFinished]				'isFinished',
					B.[FinishReported]			'isReported'
				FROM [dbo].[Process] P (NOLOCK)
				LEFT JOIN [dbo].[Batch] B (NOLOCK)
					ON B.[VCC] = P.[VCC]
						AND B.BatchTypeId = P.[Name]
				WHERE P.[VCC] = @VCC 
					AND P.[Name] = @BatchTypeId
		END 
		ELSE IF @BatchTypeName = 'STUDY'
		BEGIN
			SELECT S.[VCC]						'vcc',
					@BatchTypeName				'batchTypeName',
					S.[Name]					'batchTypeId',
					S.[Description]				'description',
					S.[Percentage]				'percentage',
					S.[Status]					'status',
					S.[StatusDescription]		'statusDescription' ,
					S.[BatchStatus]				'batchStatus',
					B.[IsFinished]				'isFinished',
					B.[FinishReported]			'isReported'
				FROM [dbo].[Study] S (NOLOCK)
				LEFT JOIN [dbo].[Batch] B (NOLOCK)
					ON B.[VCC] = S.[VCC]
						AND B.BatchTypeId = S.[Name]
				WHERE S.[VCC] = @VCC 
					AND S.[Name] = @BatchTypeId
		END 
		ELSE IF @BatchTypeName = 'EVALUATION_PLAN'
		BEGIN
			SELECT EP.[Instance]				'vcc',
					@BatchTypeName				'batchTypeName',
					EP.[ID]						'batchTypeId',
					EP.[Description]			'description',
					EP.[Percentage]				'percentage',
					EP.[Status]					'status',
					EP.[StatusDescription]		'statusDescription' ,
					EP.[BatchStatus]			'batchStatus',
					B.[IsFinished]				'isFinished',
					B.[FinishReported]			'isReported'
				FROM [dbo].[EvaluationPlan] EP (NOLOCK)
				LEFT JOIN [dbo].[Batch] B (NOLOCK)
					ON B.[VCC] = EP.[Instance]
						AND B.BatchTypeId = EP.[ID]
				WHERE EP.[Instance] = @VCC 
					AND EP.[ID] = @BatchTypeId
		END 

	END TRY
    BEGIN CATCH
        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_5.2.11_database.tar.gz: database/mssql/procedures/GetBatchDetail.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
CREATE PROCEDURE [dbo].[GetBatchDetail](
	@VCC VARCHAR(50) = NULL,
	@BatchTypeName VARCHAR(50) = NULL,
	@BatchTypeId VARCHAR(50) = NULL
)
AS
BEGIN
	-- ESTE SP TIENE LA FINALIDAD DE ACTUALIZAR LOS SALDOS DE LAS CARTERAS DEL VCC
	SET XACT_ABORT, NOCOUNT ON

	-- VERIFICAMOS QUE TENEMOS LOS PARAMETROS NECESARIOS
	IF @VCC IS NULL OR @BatchTypeName IS NULL OR @BatchTypeId IS NULL 
		-- LANZAMOS MENSAJE AVISANDO QUE FALTA ACCOUNTID
		RAISERROR('DATABASE_ERROR_MISSING_PARAMETERS', 16, 16)

	-- VERIFICAMOS QUE EL BATCH TYPE SEA UN TIPO CONOCIDO DEL SISTEMA
	IF @BatchTypeName NOT IN ('TRANSCRIPTION', 'STUDY', 'TEMPLATE', 'EVALUATION_PLAN')
		-- LANZAMOS MENSAJE AVISANDO QUE HAN SOLICITADO UNA OPERACION DESCONOCIDA
		RAISERROR('DATABASE_ERROR_UNKNOWN_BATCH_TYPENAME', 16, 16)

	-- INICIAMOS UN TRY PARA EL CASO CAIGA EN CATCH HAGAMOS ROLLBACK
    BEGIN TRY
		
		-- DEPENDIENDO DEL BATCHTYPENAME CONSULTAMOS A UNA TABLA DIFERENTE
		IF @BatchTypeName = 'TRANSCRIPTION'
		BEGIN
			-- HACEMOS LA BUSQUEDA EN LA TABLA CORRESPONDIENTE SEGUN EL TIPO DE BATCH
			SELECT P.[VCC]						'vcc',
					@BatchTypeName				'batchTypeName',
					P.[Name]					'batchTypeId',
					P.[Description]				'description',
					p.[Percentage]				'percentage',
					P.[Status]					'status',
					P.[StatusDescription]		'statusDescription',
					B.[IsFinished]				'isFinished',
					B.[FinishReported]			'isReported'
				FROM [dbo].[Process] P (NOLOCK)
				LEFT JOIN [dbo].[Batch] B (NOLOCK)
					ON B.[VCC] = P.[VCC]
						AND B.BatchTypeId = P.[Name]
				WHERE P.[VCC] = @VCC 
					AND P.[Name] = @BatchTypeId
		END 
		ELSE IF @BatchTypeName IN ('STUDY', 'TEMPLATE')
		BEGIN
			SELECT S.[VCC]						'vcc',
					@BatchTypeName				'batchTypeName',
					S.[Name]					'batchTypeId',
					S.[Description]				'description',
					S.[Percentage]				'percentage',
					S.[Status]					'status',
					S.[StatusDescription]		'statusDescription' ,
					S.[BatchStatus]				'batchStatus',
					B.[IsFinished]				'isFinished',
					B.[FinishReported]			'isReported'
				FROM [dbo].[Study] S (NOLOCK)
				LEFT JOIN [dbo].[Batch] B (NOLOCK)
					ON B.[VCC] = S.[VCC]
						AND B.BatchTypeId = S.[Name]
				WHERE S.[VCC] = @VCC 
					AND S.[Name] = @BatchTypeId
		END 
		ELSE IF @BatchTypeName = 'EVALUATION_PLAN'
		BEGIN
			SELECT EP.[Instance]				'vcc',
					@BatchTypeName				'batchTypeName',
					EP.[ID]						'batchTypeId',
					EP.[Description]			'description',
					EP.[Percentage]				'percentage',
					EP.[Status]					'status',
					EP.[StatusDescription]		'statusDescription' ,
					EP.[BatchStatus]			'batchStatus',
					B.[IsFinished]				'isFinished',
					B.[FinishReported]			'isReported'
				FROM [dbo].[EvaluationPlan] EP (NOLOCK)
				LEFT JOIN [dbo].[Batch] B (NOLOCK)
					ON B.[VCC] = EP.[Instance]
						AND B.BatchTypeId = EP.[ID]
				WHERE EP.[Instance] = @VCC 
					AND EP.[ID] = @BatchTypeId
		END 

	END TRY
    BEGIN CATCH
        DECLARE @Message nvarchar(2048) = ERROR_MESSAGE()
        DECLARE @Severity integer = ERROR_SEVERITY()
        DECLARE @State integer = ERROR_STATE()

        RAISERROR(@Message, @Severity, @State)
        RETURN -1
    END CATCH
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
